

function ZC_PrintTable (t, indent)

	if (not indent) then
		indent = 0;
	end
	
	local x
	local padding = "";
	for x = 1,indent do
		padding = padding.."  ";
	end

	ZC_chatmsg ("-------");
	
	for n, v in pairs (t) do
		if (type(v) == "table") then
			ZC_chatmsg2 (padding..n, "TABLE");
			ZC_PrintTable(v, indent+1);
		else
			ZC_chatmsg2 (padding..n, v);
		end
	end

end

-----------------------------------------

function ZC_BoolToString (b)
	if (b) then
		return "true";
	end

	return "false";
end

-----------------------------------------

function ZC_BoolToNum (b)
	if (b) then
		return 1;
	end

	return 0;
end

-----------------------------------------

function ZC_NumToBool (n)
	if (n == 0) then
		return false;
	end

	return true;
end

-----------------------------------------

function ZC_pluralizeIf (word, count)

	if (count and count == 1) then
		return word;
	else
		return ZC_pluralize(word);
	end
end

-----------------------------------------

function ZC_pluralize (word)

	return word.."s";

end

-----------------------------------------

function ZC_round (v)
	return math.floor (v + 0.5);
end

-----------------------------------------

function ZC_redmsg (msg)
	ZC_chatmsg (msg, 1, 0, 0);
end

-----------------------------------------

function ZC_pinkmsg (msg)
	ZC_chatmsg (msg, 1, .6, .6);
end

-----------------------------------------

function ZC_chatmsg (msg, red, green, blue)
	if (DEFAULT_CHAT_FRAME) then
		if (msg == nil) then
			DEFAULT_CHAT_FRAME:AddMessage ("<nil>", red, green, blue);
		else
			DEFAULT_CHAT_FRAME:AddMessage (msg, red, green, blue);
		end
	end
end

-----------------------------------------

function ZC_chatmsg2 (msg1, msg2)
	if (DEFAULT_CHAT_FRAME) then
		local msg = "";

		if (type(msg1) == "boolean") then	msg1 = ZC_BoolToString(msg1);	end;
		if (type(msg2) == "boolean") then	msg2 = ZC_BoolToString(msg2);	end;

		if (msg1 == nil) then msg = "nil";
		else				  msg = msg1;
		end

		if (msg2 == nil) then msg = msg.." nil";
		else				  msg = msg.." "..msg2;
		end

		DEFAULT_CHAT_FRAME:AddMessage (msg);
	end
end



-----------------------------------------

function ZC_val2gsc (v)
	local rv = ZC_round(v)

	local g = math.floor (rv/10000);

	rv = rv - g*10000;

	local s = math.floor (rv/100);

	rv = rv - s*100;

	local c = rv;

	return g, s, c
end

-----------------------------------------

function ZC_priceToString (val)

	local gold, silver, copper  = ZC_val2gsc(val);

	local st = "";


	if (gold ~= 0) then
		st = gold.."g ";
	end


	if (st ~= "") then
		st = st..format("%02is ", silver);
	elseif (silver ~= 0) then
		st = st..silver.."s ";
	end


	if (st ~= "") then
		st = st..format("%02ic", copper);
	elseif (copper ~= 0) then
		st = st..copper.."c";
	end

	return st;
end


-----------------------------------------

function ZC_StringSame (s1, s2)
	return (string.lower (s1) == string.lower (s2));
end

-----------------------------------------

function ZC_StringContains (s, sub)
	if (sub == nil or sub == "") then
		return false;
	end

	local start, stop = string.find (string.lower(s), string.lower(sub), 1, true);

	return (start ~= nil);
end

-----------------------------------------

function ZC_StringEndsWith (s, sub)

	if (sub == nil or sub == "") then
		return false;
	end

	local i = string.len(s) - string.len(sub);

	if (i < 0) then
		return false;
	end

	local sEnd = string.sub (s, i+1);

	return (string.lower (sEnd) == string.lower (sub));

end

-----------------------------------------

function ZC_StringStartsWith (s, sub)

	if (sub == nil or sub == "") then
		return false;
	end

	local sublen = string.len (sub);

	if (string.len (s) < sublen) then
		return false;
	end

	return (string.lower (string.sub(s, 1, sublen)) == string.lower(sub));

end

-----------------------------------------

function ZC_CopyDeep (src)

	local result = {};

	for n, v in pairs (src) do
		result[n] = v;
	end

	return result;

end

-----------------------------------------

function ZC_printstack (verbose)

	local cstr = "";

	local s = debugstack (2);

	local lines = { strsplit("\n", s) };

	local v;
	for a,v in pairs(lines) do

		local filename = nil;
		local funcname = nil;

		local a,b = string.find (v, "\\[^\\]*:");

		if (a) then
			filename = string.sub (v,a+1,b-1);
			filename = string.gsub (filename, "\.lua", "");
		end

		local a,b = string.find (v, "in function `.*\'");
		if (a) then
			funcname = string.sub (v,a+13,b-1);
		end

		if (not verbose) then
			if (funcname) then
				cstr = cstr.." > "..funcname;
			end
		else
			if (filename ~= nil and funcname ~= nil) then
				local colwid = math.floor((100 - string.len(funcname)) / 2);
				local fs = "%-"..colwid.."s (%s)";
				ZC_chatmsg (string.format (fs, funcname, filename), .5, 1, .5);
			else
				ZC_chatmsg (v);
			end
		end
	end

	if (not verbose) then
		ZC_chatmsg (cstr, .5, 1, .5);
	end

end
